@@ -10,9 +10,10 @@ use bevy_asset_loader::AssetLoader;
 use crate::theme::theme_colors::UiColors;
 use crate::{prelude::*, settings::layout_settings::LayoutMode};
 use crate::ui::viewer::TabViewerPlugin;
-use crate::viewer::control::ControlView;
+use crate::viewer::control::Control;
+use crate::viewer::control_view::ControlView;
 
-use notation_midi::prelude::{MidiPlugin, MidiState, PlayControlEvent};
+use notation_midi::prelude::{MidiPlugin, MidiState, PlayControlEvent, MidiSettings, JumpToBarEvent};
 use notation_model::prelude::*;
 
 use super::app_state::{NotationAppState, TabPathes};
@@ -123,8 +124,8 @@ impl NotationApp {
 fn insert_window_descriptor(app: &mut AppBuilder, title: String) {
     app.insert_resource(WindowDescriptor {
         title,
-        width: 1920.,
-        height: 1080.,
+        //width: 1920.,
+        //height: 1080.,
         ..WindowDescriptor::default()
     });
 }
@@ -194,9 +195,11 @@ fn handle_keyboard_inputs(
     mut app_state: ResMut<NotationAppState>,
     mut settings: ResMut<NotationSettings>,
     mut theme: ResMut<NotationTheme>,
+    midi_settings: Res<MidiSettings>,
     mut midi_state: ResMut<MidiState>,
     mut play_control_evts: EventWriter<PlayControlEvent>,
     mut window_resized_evts: EventWriter<WindowResizedEvent>,
+    mut jump_to_bar_evts: EventWriter<JumpToBarEvent>,
 ) {
     if app_state.tab.is_none() {
         return;
@@ -207,15 +210,58 @@ fn handle_keyboard_inputs(
             window_resized_evts.send(WindowResizedEvent());
         }
     } else if keyboard_input.just_released(KeyCode::Space) {
-        crate::viewer::control::ControlView::play_or_pause(&mut midi_state, &mut play_control_evts);
+        Control::play_or_pause(&mut midi_state, &mut play_control_evts);
     } else if keyboard_input.just_released(KeyCode::Return) {
-        crate::viewer::control::ControlView::play_or_stop(&mut midi_state, &mut play_control_evts);
+        Control::stop(&mut midi_state, &mut play_control_evts);
+    } else if keyboard_input.just_released(KeyCode::Home) {
+        Control::jump_to_section_start(&midi_state, &mut jump_to_bar_evts);
+    } else if keyboard_input.just_released(KeyCode::End) {
+        Control::jump_to_section_end(&midi_state, &mut jump_to_bar_evts);
+    } else if keyboard_input.just_released(KeyCode::PageUp) {
+        Control::jump_to_prev_section(&midi_state, &mut jump_to_bar_evts);
+    } else if keyboard_input.just_released(KeyCode::PageDown) {
+        Control::jump_to_next_section(&midi_state, &mut jump_to_bar_evts);
+    } else if keyboard_input.just_released(KeyCode::Left) {
+        Control::jump_to_prev_bar(&midi_state, &mut jump_to_bar_evts);
+    } else if keyboard_input.just_released(KeyCode::Right) {
+        Control::jump_to_next_bar(&midi_state, &mut jump_to_bar_evts);
+    } else if keyboard_input.just_released(KeyCode::Down) {
+        Control::seek_forward(&midi_settings, &mut midi_state, &mut play_control_evts);
     } else if keyboard_input.just_released(KeyCode::Backslash) {
-        crate::viewer::control::ControlView::toggle_layout_mode(&mut app_state, &mut settings, &mut theme);
+        Control::toggle_layout_mode(&mut app_state, &mut settings, &mut theme);
+    } else if keyboard_input.just_released(KeyCode::G) {
+        Control::toggle_show_guitar_syllable(&mut app_state, &mut settings, &mut theme);
     } else if keyboard_input.just_released(KeyCode::M) {
-        crate::viewer::control::ControlView::toggle_show_melody_syllable(&mut app_state, &mut settings, &mut theme);
+        Control::toggle_show_melody_syllable(&mut app_state, &mut settings, &mut theme);
     } else if keyboard_input.just_released(KeyCode::F) {
-        crate::viewer::control::ControlView::toggle_always_show_fret(&mut app_state, &mut settings, &mut theme);
+        Control::toggle_always_show_fret(&mut app_state, &mut settings, &mut theme);
+    } else if keyboard_input.just_released(KeyCode::L) {
+        settings.should_loop = !settings.should_loop;
+        Control::sync_should_loop(
+            &settings,
+            &mut midi_state,
+            &mut play_control_evts,
+        );
+    } else if keyboard_input.just_released(KeyCode::A) {
+        Control::set_begin_bar_ordinal(&mut midi_state, &mut play_control_evts);
+    } else if keyboard_input.just_released(KeyCode::B) {
+        Control::set_end_bar_ordinal(&mut midi_state, &mut play_control_evts);
+    } else if keyboard_input.just_released(KeyCode::C) {
+        Control::clear_begin_end(&mut midi_state, &mut play_control_evts);
+    } else if keyboard_input.just_released(KeyCode::D) {
+        Control::set_begin_bar_ordinal(&mut midi_state, &mut play_control_evts);
+        Control::set_end_bar_ordinal(&mut midi_state, &mut play_control_evts);
+    } else if keyboard_input.just_released(KeyCode::E) {
+        Control::set_begin_bar_ordinal(&mut midi_state, &mut play_control_evts);
+        Control::set_end_bar_ordinal(&mut midi_state, &mut play_control_evts);
+    } else if keyboard_input.just_released(KeyCode::Key1) {
+        Control::set_speed_factor(&mut settings, &mut midi_state, &mut play_control_evts, 0.25);
+    } else if keyboard_input.just_released(KeyCode::Key2) {
+        Control::set_speed_factor(&mut settings, &mut midi_state, &mut play_control_evts, 0.5);
+    } else if keyboard_input.just_released(KeyCode::Key3) {
+        Control::set_speed_factor(&mut settings, &mut midi_state, &mut play_control_evts, 0.75);
+    } else if keyboard_input.just_released(KeyCode::Key4) {
+        Control::set_speed_factor(&mut settings, &mut midi_state, &mut play_control_evts, 1.0);
     }
 }
 
