@@ -20,11 +20,10 @@ use super::guitar_string::{GuitarStringData};
 #[derive(Clone, Debug)]
 pub struct GuitarView {
     pub tab: Arc<Tab>,
-    pub syllable: Syllable,
 }
 impl GuitarView {
-    pub fn new(tab: Arc<Tab>, syllable: Syllable) -> Self {
-        Self { tab, syllable }
+    pub fn new(tab: Arc<Tab>) -> Self {
+        Self { tab }
     }
 }
 impl Display for GuitarView {
@@ -52,7 +51,7 @@ impl GuitarView {
         let guitar_entity = BevyUtil::spawn_child_bundle(
             commands,
             entity,
-            ViewBundle::from(GuitarView::new(tab.clone(), Syllable::default())),
+            ViewBundle::from(GuitarView::new(tab.clone())),
         );
         let sprite_bundle = SpriteBundle {
             sprite: Sprite::new(Vec2::new(
@@ -168,6 +167,8 @@ impl GuitarView {
     }
     pub fn update_string_state(
         mut commands: Commands,
+        assets: Res<NotationAssets>,
+        settings: Res<NotationSettings>,
         midi_state: Res<MidiState>,
         time: Res<Time>,
         theme: Res<NotationTheme>,
@@ -231,14 +232,16 @@ impl GuitarView {
                             finger_entity,
                         );
                     }
-                    finger_data.update(&mut commands, &theme, finger_entity);
+                    finger_data.update_with_syllable(&mut commands, &assets, &theme, &settings, finger_entity);
                 }
             }
         }
     }
     pub fn update_hand_shape6(
         mut commands: Commands,
+        assets: Res<NotationAssets>,
         theme: Res<NotationTheme>,
+        settings: Res<NotationSettings>,
         query: Query<(&Arc<LaneEntry>, &HandShape6, &EntryPlaying), Changed<EntryPlaying>>,
         mut finger_query: Query<(Entity, &mut FretFingerData), With<FretFingerData>>,
         mut string_query: Query<(Entity, &mut GuitarStringData), With<GuitarStringData>>,
@@ -282,7 +285,7 @@ impl GuitarView {
                     Some(&dot_query),
                     finger_entity,
                 );
-                finger_data.update(&mut commands, &theme, finger_entity);
+                finger_data.update_with_syllable(&mut commands, &assets, &theme, &settings, finger_entity);
             }
             for (string_entity, mut string_data) in string_query.iter_mut() {
                 string_data.update_value(shape, fretboard, pick, meta.clone());
