@@ -27,22 +27,40 @@ impl Default for LayoutMode {
     }
 }
 
+#[derive(Copy, Clone, PartialEq, Eq, Serialize, Deserialize, Debug)]
+#[cfg_attr(feature = "inspector", derive(Inspectable))]
+pub enum GridAlignMode {
+    Center,
+    ForceCenter,
+    Top,
+    ForceTop,
+}
+impl Default for GridAlignMode {
+    fn default() -> Self {
+        Self::Center
+    }
+}
+
 #[derive(Clone, Serialize, Deserialize, Debug)]
 #[cfg_attr(feature = "inspector", derive(Inspectable))]
 pub struct LayoutSettings {
     pub mode: LayoutMode,
+    pub grid_align_mode: GridAlignMode,
     pub focus_bar_ease_ms: u64,
     pub focusing_bar_ordinal: usize,
-    pub try_show_last_row_in_grid_mode: bool,
+    pub video_recording_mode: bool,
+    pub override_focus_offset_y: Option<f32>,
 }
 
 impl Default for LayoutSettings {
     fn default() -> Self {
         Self {
             mode: LayoutMode::default(),
+            grid_align_mode: GridAlignMode::default(),
             focus_bar_ease_ms: 250,
             focusing_bar_ordinal: usize::MAX,
-            try_show_last_row_in_grid_mode: true,
+            video_recording_mode: false,
+            override_focus_offset_y: None,
         }
     }
 }
@@ -79,11 +97,11 @@ impl LayoutSettings {
             let (x, y) = match self.mode {
                 LayoutMode::Grid => {
                     let mut y = trans.y + delta_y;
-                    let min_y = layout.offset.y + grid_data.offset.y - theme.sizes.layout.margin;
+                    let min_y = layout.offset.y + grid_data.offset.y - theme.sizes.layout.page_margin;
                     if y < min_y {
                         y = min_y;
                     } else {
-                        let max_y = layout.offset.y + theme.sizes.layout.margin + grid_data.content_size.height - grid_data.grid_size.height;
+                        let max_y = layout.offset.y + theme.sizes.layout.page_margin + grid_data.content_size.height - grid_data.grid_size.height;
                         if y > max_y {
                             y = max_y;
                         }
@@ -146,23 +164,41 @@ impl LayoutSettings {
         grid_data: &GridData,
         pos_data: &PosIndicatorData,
     ) -> f32 {
-        let (row, col) = grid_data.calc_row_col(pos_data.bar_position.bar_ordinal);
+        let (_row, col) = grid_data.calc_row_col(pos_data.bar_position.bar_ordinal);
         let mut y = pos_data.bar_layout.offset.y;
         let grid_size = layout.size;
         let content_size = grid_data.content_size;
-        if grid_size.height > content_size.height {
-            y = -(grid_size.height - content_size.height);
-        } else if row > 0 && self.try_show_last_row_in_grid_mode {
-            let last_row_height = grid_data.calc_cell_size(row - 1, col).height;
-            if last_row_height + pos_data.bar_layout.size.height <= grid_size.height / 2.0 {
-                y = grid_data.calc_cell_offset(row - 1, col).y;
-            }
-            let min_y = grid_size.height - content_size.height - theme.sizes.layout.margin * 2.0;
-            if y < min_y {
-                y = min_y;
+        if self.video_recording_mode || self.grid_align_mode == GridAlignMode::ForceTop {
+            y += self.override_focus_offset_y.unwrap_or(0.0);
+        } else {
+            if grid_size.height > content_size.height {
+                y = -(grid_size.height - content_size.height);
+            } else {
+                /* try to show as 2nd row
+                let last_row_height = grid_data.calc_cell_size(row - 1, col).height;
+                if last_row_height + pos_data.bar_layout.size.height <= grid_size.height / 2.0 {
+                    y = grid_data.calc_cell_offset(row - 1, col).y;
+                }
+                 */
+                if self.grid_align_mode == GridAlignMode::Center
+                    || self.grid_align_mode == GridAlignMode::ForceCenter {
+                    y += (grid_size.height - grid_data.margin.height * 2.0 - pos_data.bar_layout.size.height) / 2.0 + self.override_focus_offset_y.unwrap_or(0.0);
+                }
+                if self.grid_align_mode != GridAlignMode::ForceCenter
+                    && self.grid_align_mode != GridAlignMode::ForceTop {
+                    let min_y = grid_size.height - content_size.height - theme.sizes.layout.page_margin * 2.0;
+                    if y < min_y {
+                        y = min_y;
+                    } else {
+                        let max_y = grid_data.calc_cell_offset(0, col).y;
+                        if y > max_y {
+                            y = max_y;
+                        }
+                    }
+                }
             }
         }
-        y - layout.offset.y - grid_data.offset.y + theme.sizes.layout.margin
+        y - layout.offset.y - grid_data.offset.y + theme.sizes.layout.page_margin
     }
     fn calc_line_focus_xy(
         &self,
@@ -193,7 +229,7 @@ impl LayoutSettings {
         let content_size = grid_data.content_size;
         let y = pos_data.bar_layout.offset.y + grid_size.height
             - content_size.height
-            - theme.sizes.layout.margin;
+            - theme.sizes.layout.page_margin;
         (
             x - layout.offset.x - grid_data.offset.x,
             y - layout.offset.y,
