@@ -63,7 +63,7 @@ impl<'a> GridView<NotationLayout<'a>, BarView> for TabBars {
             0.0,
             self.tab.bars.len(),
         );
-        let margin = engine.theme.sizes.layout.bar_margin();
+        let cell_margin = engine.theme.sizes.cell_margin(&engine.settings);
         if engine.settings.layout.mode == LayoutMode::Line {
             let height = self
                 .bar_layouts
@@ -79,7 +79,7 @@ impl<'a> GridView<NotationLayout<'a>, BarView> for TabBars {
                 1,
                 self.tab.bars.len(),
                 size,
-                margin,
+                cell_margin,
                 LayoutAnchor::TOP_LEFT,
                 grid_size,
             );
@@ -94,7 +94,7 @@ impl<'a> GridView<NotationLayout<'a>, BarView> for TabBars {
                 for col in 0..cols {
                     if let Some(bar_layout) = self.bar_layouts.get(row * cols + col) {
                         for lane_layout in bar_layout.lane_layouts.iter() {
-                            if !lane_layout.is_ghost() {
+                            if engine.settings.layout.video_recording_mode || !lane_layout.is_ghost() {
                                 non_ghost_lanes.insert(lane_layout.id());
                             }
                         }
@@ -117,7 +117,7 @@ impl<'a> GridView<NotationLayout<'a>, BarView> for TabBars {
                 rows,
                 cols,
                 row_sizes,
-                margin,
+                cell_margin,
                 LayoutAnchor::TOP_LEFT,
                 grid_size,
             )
@@ -136,7 +136,7 @@ impl TabBars {
             for lane in bar.lanes.iter() {
                 let lane_id = lane.id();
                 if !lane_layouts.contains_key(&lane_id) {
-                    let height = theme.sizes.calc_lane_height(lane.kind);
+                    let height = theme.sizes.calc_lane_height(settings, lane.kind);
                     let margin = theme.sizes.layout.lane_margin;
                     lane_layouts.insert(lane_id, LaneLayoutData::new(&lane, height, margin));
                 }
@@ -148,7 +148,11 @@ impl TabBars {
             .collect::<Vec<LaneLayoutData>>();
         settings.layout.sort_lane_layouts(&result)
     }
-    fn calc_bar_layout_data(all_lane_layouts: &Vec<LaneLayoutData>, bar: &TabBar) -> BarLayoutData {
+    fn calc_bar_layout_data(
+        theme: &NotationTheme,
+        all_lane_layouts: &Vec<LaneLayoutData>,
+        bar: &TabBar
+    ) -> BarLayoutData {
         let mut lane_layouts = Vec::new();
         for lane_layout in all_lane_layouts.iter() {
             let lane =
@@ -159,7 +163,7 @@ impl TabBars {
                 ..lane_layout.clone()
             }));
         }
-        BarLayoutData::new(bar.props, lane_layouts)
+        BarLayoutData::new(theme.sizes.layout.bar_min_height, bar.props, lane_layouts)
     }
     pub fn calc_bar_layouts(
         theme: &NotationTheme,
@@ -169,7 +173,7 @@ impl TabBars {
         let all_lane_layouts = Self::calc_all_lane_layouts(theme, settings, tab);
         tab.bars
             .iter()
-            .map(|bar| Self::calc_bar_layout_data(&all_lane_layouts, bar))
+            .map(|bar| Self::calc_bar_layout_data(theme, &all_lane_layouts, bar))
             .collect()
     }
 }
