@@ -2,7 +2,7 @@ use std::sync::Arc;
 
 use bevy::prelude::*;
 use notation_bevy_utils::prelude::{LayoutData, GridData};
-use notation_midi::prelude::{JumpToBarEvent, MidiState, PlayControlEvent};
+use notation_midi::prelude::{JumpToBarEvent, MidiState, PlayControlEvent, MidiSettings};
 use notation_model::prelude::TabBarProps;
 
 use crate::bar::bar_view::BarView;
@@ -16,7 +16,8 @@ use crate::prelude::{
 };
 use crate::rhythm::rhythm_bar::{RhythmBarData};
 use crate::rhythm::rhythm_view::RhythmView;
-use crate::viewer::control::ControlView;
+use crate::viewer::control::Control;
+use crate::viewer::control_view::ControlView;
 
 use super::tab_asset::TabAssetLoader;
 
@@ -60,7 +61,7 @@ impl Plugin for TabPlugin {
     }
 }
 
-fn jump_to_bar(
+pub fn jump_to_bar(
     jump_to_bar_evts: &mut EventWriter<JumpToBarEvent>,
     bar_props: TabBarProps,
 ) {
@@ -78,7 +79,9 @@ fn on_mouse_clicked(
     rhythm_query: Query<(&Arc<RhythmView>, &LayoutData, &GlobalTransform)>,
     chord_query: Query<(&Arc<ChordView>, &LayoutData, &GlobalTransform)>,
     bar_query: Query<(&Arc<BarView>, &LayoutData, &GlobalTransform)>,
+    tab_control_query: Query<(&Arc<TabControl>, &LayoutData, &GlobalTransform)>,
     mut jump_to_bar_evts: EventWriter<JumpToBarEvent>,
+    midi_settings: Res<MidiSettings>,
     mut midi_state: ResMut<MidiState>,
     mut play_control_evts: EventWriter<PlayControlEvent>,
 ) {
@@ -96,7 +99,7 @@ fn on_mouse_clicked(
             println!("tab_plugin::on_mouse_clicked() -> {:?}", pos);
             for (mini_bar, layout, global_transform) in mini_bar_query.iter() {
                 if layout.is_pos_inside(pos, global_transform) {
-                    jump_to_bar( &mut jump_to_bar_evts, mini_bar.bar_props);
+                    jump_to_bar(&mut jump_to_bar_evts, mini_bar.bar_props);
                     return;
                 }
             }
@@ -104,19 +107,19 @@ fn on_mouse_clicked(
                 if layout.is_pos_inside(pos, global_transform) {
                     match button.action {
                         crate::play::play_button::PlayButtonAction::PlayPause =>
-                            crate::viewer::control::ControlView::play_or_pause(&mut midi_state, &mut play_control_evts),
+                            Control::play_or_pause(&mut midi_state, &mut play_control_evts),
                         crate::play::play_button::PlayButtonAction::Stop =>
-                            crate::viewer::control::ControlView::stop(&mut midi_state, &mut play_control_evts),
+                            Control::stop(&mut midi_state, &mut play_control_evts),
                         crate::play::play_button::PlayButtonAction::LoopMode => {
                             settings.should_loop = !settings.should_loop;
-                            crate::viewer::control::ControlView::sync_should_loop(&settings, &mut midi_state, &mut play_control_evts)
+                            Control::sync_should_loop(&settings, &mut midi_state, &mut play_control_evts)
                         }
                         crate::play::play_button::PlayButtonAction::SetBegin =>
-                            crate::viewer::control::ControlView::set_begin_bar_ordinal(&mut midi_state, &mut play_control_evts),
+                            Control::set_begin_bar_ordinal(&mut midi_state, &mut play_control_evts),
                         crate::play::play_button::PlayButtonAction::SetEnd =>
-                            crate::viewer::control::ControlView::set_end_bar_ordinal(&mut midi_state, &mut play_control_evts),
+                            Control::set_end_bar_ordinal(&mut midi_state, &mut play_control_evts),
                         crate::play::play_button::PlayButtonAction::Clear =>
-                            crate::viewer::control::ControlView::clear_begin_end(&mut midi_state, &mut play_control_evts),
+                            Control::clear_begin_end(&mut midi_state, &mut play_control_evts),
                     }
                     return;
                 }
@@ -145,6 +148,13 @@ fn on_mouse_clicked(
                     return;
                 }
             }
+            // Not using GuitarView here, since it 's y position been changed to adjust with capo position
+            for (_tab_control, layout, global_transform) in tab_control_query.iter() {
+                if layout.is_pos_inside(pos, global_transform) {
+                    Control::seek_forward(&midi_settings, &mut midi_state, &mut play_control_evts);
+                    return;
+                }
+            }
         }
     }
 }
