@@ -1,10 +1,12 @@
 use notation_bevy_utils::prelude::LayoutSize;
-use notation_model::prelude::{LaneKind, PlayingState, Octave, SyllableNote, Semitones};
+use notation_model::prelude::{LaneKind, PlayingState, Semitones, TrackKind, Tab, Note};
 use serde::{Deserialize, Serialize};
 
 #[cfg(feature = "inspector")]
 use bevy_inspector_egui::Inspectable;
 
+use crate::prelude::NotationSettings;
+
 #[derive(Copy, Clone, PartialEq, Serialize, Deserialize, Debug)]
 #[cfg_attr(feature = "inspector", derive(Inspectable))]
 pub struct PlayingSize {
@@ -56,7 +58,7 @@ pub struct BarSizes {
 impl Default for BarSizes {
     fn default() -> Self {
         Self {
-            beat_size_range: (64.0, 256.0),
+            beat_size_range: (80.0, 256.0),
             bar_separator_extra: 3.0,
             bar_separator_size: 3.0,
             bar_beat_extra: 0.0,
@@ -114,7 +116,9 @@ pub struct MelodySizes {
     pub note_height: f32,
     pub note_outline: PlayingSize,
     pub semitone_height: f32,
-    pub semitones: usize,
+    pub lowest: Semitones,
+    pub highest: Semitones,
+    pub syllable_height: f32
 }
 impl Default for MelodySizes {
     fn default() -> Self {
@@ -122,20 +126,52 @@ impl Default for MelodySizes {
             note_height: 4.0,
             note_outline: PlayingSize::new(1.0, 1.5, 1.0),
             semitone_height: 2.0,
-            semitones: 24,
+            lowest: Semitones(i8::MAX),
+            highest: Semitones(i8::MIN),
+            syllable_height: 16.0,
         }
     }
 }
 impl MelodySizes {
-    pub fn calc_note_y(&self, syllable_note: SyllableNote) -> f32 {
-        let center_octave = Octave::default(); //TODO
-        let center_semitons = Semitones::from(center_octave);
-        let offset_semitones = Semitones::from(syllable_note) - center_semitons;
-        let center_y = self.semitones as f32 * self.semitone_height / 2.0;
-        -center_y + self.semitone_height * offset_semitones.0 as f32
+    pub fn update_with_tab(&mut self, tab: &Tab) {
+        let default = Self::default();
+        self.lowest = default.lowest;
+        self.highest = default.highest;
+        if let Some (track) = tab.get_track_of_kind(TrackKind::Vocal) {
+            for entry in track.entries.iter() {
+                if let Some(entry) = entry.proto.as_core() {
+                    if let Some(tone) = entry.as_tone() {
+                        for note in tone.get_notes() {
+                            let v = Semitones::from(note);
+                            if v < self.lowest {
+                                self.lowest = v
+                            }
+                            if v > self.highest {
+                                self.highest = v
+                            }
+                        }
+                    }
+                }
+            }
+            println!("MelodySizes::update_with_tab: {} - {}", self.lowest.0, self.highest.0);
+        }
     }
-    pub fn layout_height(&self) -> f32 {
-        self.semitones as f32 * self.semitone_height + self.note_height
+    pub fn calc_note_y(&self, note: Note) -> f32 {
+        let offset_semitones = self.highest - Semitones::from(note);
+        -1.0 * self.semitone_height * offset_semitones.0 as f32 - self.note_height
+    }
+    pub fn layout_height(&self, settings: &NotationSettings) -> f32 {
+        let range = if self.highest > self.lowest {
+            self.highest.0 - self.lowest.0 + 1
+        } else {
+            1
+        };
+        let height = range as f32 * self.semitone_height + self.note_height;
+        if settings.show_melody_syllable {
+            height + self.syllable_height
+        } else {
+            height
+        }
     }
 }
 
@@ -177,7 +213,12 @@ impl Default for StringsSizes {
 }
 impl StringsSizes {
     pub fn layout_height(&self) -> f32 {
-        self.string_space * 6.0 + self.note_height
+        self.string_space * 6.0
+    }
+    pub fn calc_string_y(&self, string: u8) -> f32 {
+        -1.0
+            * self.string_space
+            * (string as f32 - 0.5)
     }
 }
 
@@ -246,34 +287,39 @@ impl MiniMapSizes {
 #[derive(Copy, Clone, PartialEq, Serialize, Deserialize, Debug)]
 #[cfg_attr(feature = "inspector", derive(Inspectable))]
 pub struct LayoutSizes {
-    pub margin: f32,
+    pub page_margin: f32,
     pub bar_margin: f32,
     pub lane_margin: f32,
+    pub bar_min_height: f32,
     pub shapes_height: f32,
 }
 
 impl Default for LayoutSizes {
     fn default() -> Self {
         Self {
-            margin: 20.0,
-            bar_margin: 12.0,
-            lane_margin: 2.0,
-            shapes_height: 46.0,
+            page_margin: 12.0,
+            bar_margin: 16.0,
+            lane_margin: 3.0,
+            bar_min_height: 24.0,
+            shapes_height: 52.0,
         }
     }
 }
-impl LayoutSizes {
-    pub fn bar_margin(&self) -> LayoutSize {
-        LayoutSize::new(0.0, self.bar_margin)
-    }
-}
 impl ThemeSizes {
-    pub fn calc_lane_height(&self, lane_kind: LaneKind) -> f32 {
+    pub fn cell_margin(&self, setting: &NotationSettings) -> LayoutSize {
+        let height = if setting.layout.video_recording_mode {
+            self.layout.bar_margin * 4.0
+        } else {
+            self.layout.bar_margin
+        };
+        LayoutSize::new(0.0, height)
+    }
+    pub fn calc_lane_height(&self, settings: &NotationSettings, lane_kind: LaneKind) -> f32 {
         match lane_kind {
-            LaneKind::Lyrics => self.lyrics.layout_height(),
-            LaneKind::Melody => self.melody.layout_height(),
-            LaneKind::Strings => self.strings.layout_height(),
-            LaneKind::Shapes => self.layout.shapes_height,
+            LaneKind::Lyrics => if settings.hide_lyrics_lane { 0.0 } else { self.lyrics.layout_height() },
+            LaneKind::Melody => if settings.hide_melody_lane { 0.0 } else { self.melody.layout_height(settings) },
+            LaneKind::Strings => if settings.hide_strings_lane { 0.0 } else { self.strings.layout_height() },
+            LaneKind::Shapes => if settings.hide_shapes_lane { 0.0 } else { self.layout.shapes_height },
             _ => 0.0,
         }
     }
