@@ -79,7 +79,7 @@ impl Default for ChordTexts {
     fn default() -> Self {
         Self {
             bars_font_size: 16.0,
-            bars_font_color: ThemeColors::hex_linear("333333"),
+            bars_font_color: ThemeColors::hex_linear("FFFFFF"),
             bars_x: 6.0,
             bars_y: -6.0,
         }
@@ -92,6 +92,7 @@ impl ChordTexts {
         assets: &NotationAssets,
         entity: Entity,
         text: &str,
+        z: f32,
     ) {
         //NOTE: not sure why, using HorizontalAlign::Right here got the left behaviour
         BevyUtil::spawn_text(
@@ -105,7 +106,7 @@ impl ChordTexts {
             VerticalAlign::Bottom,
             self.bars_x,
             self.bars_y,
-            30.0,
+            z,
         );
     }
     pub fn update_bars_xy(&self, transform: &mut Transform, layout: &LayoutData) {
@@ -168,7 +169,7 @@ impl Default for LyricsTexts {
     fn default() -> Self {
         Self {
             text_x: 4.0,
-            text_y: 2.0,
+            text_y: -8.0,
             text_z: 1.0,
             word_font_size: 20.0,
             word_font_color: Color::hex("000000").unwrap(),
@@ -206,6 +207,7 @@ pub struct MelodyTexts {
     pub text_x: f32,
     pub text_y: f32,
     pub text_z: f32,
+    pub horizontal_center: bool,
     pub syllable_font_size: f32,
     pub syllable_font_color: Color,
 }
@@ -213,8 +215,9 @@ impl Default for MelodyTexts {
     fn default() -> Self {
         Self {
             text_x: 4.0,
-            text_y: -12.0,
+            text_y: -14.0,
             text_z: 1.0,
+            horizontal_center: false,
             syllable_font_size: 16.0,
             syllable_font_color: Color::hex("000000").unwrap(),
         }
@@ -228,6 +231,17 @@ impl MelodyTexts {
         assets: &NotationAssets,
         settings: &NotationSettings,
         syllable: &Syllable,
+    ) {
+        self.spawn_scaled_syllable_text(commands, entity, assets, settings, syllable, 1.0);
+    }
+    pub fn spawn_scaled_syllable_text(
+        &self,
+        commands: &mut Commands,
+        entity: Entity,
+        assets: &NotationAssets,
+        settings: &NotationSettings,
+        syllable: &Syllable,
+        scale: f32,
     ) {
         let text = if settings.show_syllable_as_num {
             syllable.to_text()
@@ -240,12 +254,12 @@ impl MelodyTexts {
             entity,
             text.as_str(),
             assets.en_font.clone(),
-            self.syllable_font_size,
+            self.syllable_font_size * scale,
             self.syllable_font_color,
-            HorizontalAlign::Right,
+            if self.horizontal_center { HorizontalAlign::Center } else { HorizontalAlign::Right } ,
             VerticalAlign::Center,
-            self.text_x,
-            self.text_y,
+            self.text_x * scale,
+            self.text_y * scale,
             self.text_z,
         );
     }
