@@ -42,8 +42,8 @@ impl Plugin for TabViewerPlugin {
         app.add_system_set(
             SystemSet::on_update(NotationAssetsStates::Loaded)
                 .with_system(GuitarView::on_layout_changed.system())
-                .with_system(GuitarView::update_string_state.system())
-                .with_system(GuitarView::update_hand_shape6.system())
+                .with_system(GuitarView::update_hand_shape6.system().label("GuitarView::update_hand_shape6"))
+                .with_system(GuitarView::update_string_state.system().label("GuitarView::update_string_state").after("GuitarView::update_hand_shape6"))
                 .with_system(GuitarView::adjust_y_by_capo.system())
                 .with_system(TabViewer::do_layout.system()),
         );
