@@ -17,7 +17,7 @@ use crate::prelude::{
 use crate::ui::layout::NotationLayout;
 use crate::ui::viewer::TabViewer;
 
-use super::control::ControlView;
+use super::control_view::ControlView;
 
 pub struct NotationViewer {
     pub uuid: Uuid,
@@ -48,8 +48,8 @@ impl NotationViewer {
         mut commands: Commands,
         mut materials: ResMut<Assets<ColorMaterial>>,
         assets: Res<NotationAssets>,
-        theme: Res<NotationTheme>,
-        settings: Res<NotationSettings>,
+        mut theme: ResMut<NotationTheme>,
+        mut settings: ResMut<NotationSettings>,
         mut switch_tab_evts: EventWriter<SwitchTabEvent>,
     ) {
         let mut tab = None;
@@ -57,6 +57,7 @@ impl NotationViewer {
             tab = Some(evt.0.clone());
         }
         if let Some(tab) = tab {
+            theme.sizes.melody.update_with_tab(&tab);
             let viewer_bundle = ViewBundle::from(NotationViewer::new(tab.clone()));
             let entity = commands.spawn_bundle(viewer_bundle).id();
             ControlView::spawn(
@@ -77,6 +78,7 @@ impl NotationViewer {
                 entity,
                 &tab,
             );
+            settings.layout.focusing_bar_ordinal = usize::MAX;
             switch_tab_evts.send(SwitchTabEvent::new(tab));
         }
     }
